/*
 * (C) Copyright 2011- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */

#ifndef eccodes_ecbuild_config_h
#define eccodes_ecbuild_config_h

/* ecbuild info */

#ifndef ECBUILD_VERSION_STR
#define ECBUILD_VERSION_STR "3.6.3"
#endif
#ifndef ECBUILD_VERSION
#define ECBUILD_VERSION "3.6.3"
#endif
#ifndef ECBUILD_MACROS_DIR
#define ECBUILD_MACROS_DIR  "/pub/devel/eccodes/eccodes-2.23.0-1.x86_64/src/eccodes-2.23.0-Source/cmake"
#endif

/* config info */

#define ECCODES_OS_NAME          "CYGWIN-3.2.0(0.340/5/3)"
#define ECCODES_OS_BITS          64
#define ECCODES_OS_BITS_STR      "64"
#define ECCODES_OS_STR           "UNKNOWN.64"
#define ECCODES_OS_VERSION       "3.2.0(0.340/5/3)"
#define ECCODES_SYS_PROCESSOR    "x86_64"

#define ECCODES_BUILD_TIMESTAMP  "20210930113151"
#define ECCODES_BUILD_TYPE       "RelWithDebInfo"

#define ECCODES_C_COMPILER_ID      "GNU"
#define ECCODES_C_COMPILER_VERSION "10.2.0"

#define ECCODES_CXX_COMPILER_ID      ""
#define ECCODES_CXX_COMPILER_VERSION ""

#define ECCODES_C_COMPILER       "/usr/bin/gcc.exe"
#define ECCODES_C_FLAGS          "-ggdb -O2 -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -fdebug-prefix-map=/pub/devel/eccodes/eccodes-2.23.0-1.x86_64/build=/usr/src/debug/eccodes-2.23.0-1 -fdebug-prefix-map=/pub/devel/eccodes/eccodes-2.23.0-1.x86_64/src/eccodes-2.23.0-Source=/usr/src/debug/eccodes-2.23.0-1 -pipe -O2 -g -DNDEBUG"

#define ECCODES_CXX_COMPILER     "/usr/bin/g++.exe"
#define ECCODES_CXX_FLAGS        ""

/* Needed for finding per package config files */

#define ECCODES_INSTALL_DIR       "/usr"
#define ECCODES_INSTALL_BIN_DIR   "/usr/bin"
#define ECCODES_INSTALL_LIB_DIR   "/usr/lib"
#define ECCODES_INSTALL_DATA_DIR  "/usr/share/eccodes"

#define ECCODES_DEVELOPER_SRC_DIR "/pub/devel/eccodes/eccodes-2.23.0-1.x86_64/src/eccodes-2.23.0-Source"
#define ECCODES_DEVELOPER_BIN_DIR "/pub/devel/eccodes/eccodes-2.23.0-1.x86_64/build"

/* Fortran support */

#if 1

#define ECCODES_Fortran_COMPILER_ID      "GNU"
#define ECCODES_Fortran_COMPILER_VERSION "10.2.0"

#define ECCODES_Fortran_COMPILER "/usr/bin/gfortran.exe"
#define ECCODES_Fortran_FLAGS    "-ggdb -O2 -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong --param=ssp-buffer-size=4 -fdebug-prefix-map=/pub/devel/eccodes/eccodes-2.23.0-1.x86_64/build=/usr/src/debug/eccodes-2.23.0-1 -fdebug-prefix-map=/pub/devel/eccodes/eccodes-2.23.0-1.x86_64/src/eccodes-2.23.0-Source=/usr/src/debug/eccodes-2.23.0-1 -O2 -g -DNDEBUG"

#endif

#endif /* eccodes_ecbuild_config_h */
